@@ -14,13 +14,14 @@ class GerritChange(BaseModel):
     def __init__(self, **kwargs):
         self.revisions = {}
         self.current_revision_number = 0
-        super(GerritChange, self).__init__(**kwargs)
+        super().__init__(**kwargs)
+        self.endpoint = f"/changes/{self.id}"
 
     def create_merge_patch_set(self, input_):
         """
         Update an existing change by using a MergePatchSetInput entity.
-        Gerrit will create a merge commit based on the information of MergePatchSetInput and add a new patch set to
-        the change corresponding to the new merge commit.
+        Gerrit will create a merge commit based on the information of MergePatchSetInput and add
+        a new patch set to the change corresponding to the new merge commit.
 
         .. code-block:: python
 
@@ -31,20 +32,16 @@ class GerritChange(BaseModel):
                 }
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.update(input_)
 
         :param input_: the MergePatchSetInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#merge-patch-set-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
+          #merge-patch-set-input
         :return:
         """
-        endpoint = "/changes/%s/merge" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/merge",
+                                json=input_, headers=self.gerrit.default_headers)
 
     def set_commit_message(self, input_):
         """
@@ -53,23 +50,19 @@ class GerritChange(BaseModel):
         .. code-block:: python
 
             input_ = {
-                "message": "New Commit message \\n\\nChange-Id: I10394472cbd17dd12454f229e4f6de00b143a444\\n"
+                "message": "New Commit message \\n\\nChange-Id: I10394472cbd17dd12454f22b143a444\\n"
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.set_commit_message(input_)
 
         :param input_: the CommitMessageInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#commit-message-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
+          #commit-message-input
         :return:
         """
-        endpoint = "/changes/%s/message" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/message",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def list_votes(self, account):
         """
@@ -78,16 +71,14 @@ class GerritChange(BaseModel):
         :param account: account id or username
         :return:
         """
-        endpoint = "/changes/%s/reviewers/%s/votes" % (self.id, account)
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + f"/reviewers/{account}/votes")
 
     def delete_vote(self, account, label, input_=None):
         """
-        Deletes a single vote from a change. Note, that even when the last vote of a reviewer is removed the reviewer
-        itself is still listed on the change.
-        If another user removed a user’s vote, the user with the deleted vote will be added to the attention set.
+        Deletes a single vote from a change. Note, that even when the last vote of a reviewer is
+        removed the reviewer itself is still listed on the change.
+        If another user removed a user’s vote, the user with the deleted vote will be added to
+        the attention set.
 
         .. code-block:: python
 
@@ -95,7 +86,7 @@ class GerritChange(BaseModel):
                 "notify": "NONE"
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             change.delete_vote('John', 'Code-Review', input_)
             # or
             change.delete_vote('John', 'Code-Review')
@@ -103,26 +94,16 @@ class GerritChange(BaseModel):
         :param account:
         :param label:
         :param input_: the DeleteVoteInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#delete-vote-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
+          #delete-vote-input
         :return:
         """
+        endpoint = f"/changes/{self.change}/reviewers/{account}/votes/{label}"
         if input_ is None:
-            endpoint = "/changes/%s/reviewers/%s/votes/%s" % (
-                self.change,
-                account,
-                label,
-            )
-            self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+            self.gerrit.delete(endpoint)
         else:
-            endpoint = "/changes/%s/reviewers/%s/votes/%s/delete" % (
-                self.change,
-                account,
-                label,
-            )
-            base_url = self.gerrit.get_endpoint_url(endpoint)
-            self.gerrit.requester.post(
-                base_url, json=input_, headers=self.gerrit.default_headers
-            )
+            endpoint += "/delete"
+            self.gerrit.post(endpoint, json=input_, headers=self.gerrit.default_headers)
 
     def get_topic(self):
         """
@@ -134,10 +115,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/topic" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(f"/changes/{self.id}/topic")
 
     def set_topic(self, topic):
         """
@@ -146,14 +124,9 @@ class GerritChange(BaseModel):
         :param topic: The new topic
         :return:
         """
-        endpoint = "/changes/%s/topic" % self.id
         input_ = {"topic": topic}
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(self.endpoint + "/topic",
+                               json=input_, headers=self.gerrit.default_headers)
 
     def delete_topic(self):
         """
@@ -161,8 +134,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/topic" % self.id
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(f"/changes/{self.id}/topic")
 
     def get_assignee(self):
         """
@@ -170,9 +142,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/assignee" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + "/assignee")
         if result:
             username = result.get("username")
             return self.gerrit.accounts.get(username)
@@ -187,32 +157,27 @@ class GerritChange(BaseModel):
                 "assignee": "jhon.doe"
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.set_assignee(input_)
 
         :param input_: the AssigneeInput entity,
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#assignee-input
         :return:
         """
-        endpoint = "/changes/%s/assignee" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.put(self.endpoint + "/assignee",
+                                 json=input_, headers=self.gerrit.default_headers)
         if result:
             username = result.get("username")
             return self.gerrit.accounts.get(username)
 
     def get_past_assignees(self):
         """
-        Returns a list of every user ever assigned to a change, in the order in which they were first assigned.
+        Returns a list of every user ever assigned to a change, in the order in which they were
+        first assigned.
 
         :return:
         """
-        endpoint = "/changes/%s/past_assignees" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + "/past_assignees")
         assignees = []
         if result:
             for item in result:
@@ -228,8 +193,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/assignee" % self.id
-        response = self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        response = self.gerrit.delete(self.endpoint + "/assignee")
         result = self.gerrit.decode_response(response)
 
         if result:
@@ -243,41 +207,34 @@ class GerritChange(BaseModel):
         :param commit: commit id
         :return:
         """
-        endpoint = "/changes/%s/pure_revert?o=%s" % (self.id, commit)
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + f"/pure_revert?o={commit}")
 
     def abandon(self):
         """
         Abandons a change.
         Abandoning a change also removes all users from the attention set.
-        If the change cannot be abandoned because the change state doesn’t allow abandoning of the change,
-        the response is “409 Conflict” and the error message is contained in the response body.
+        If the change cannot be abandoned because the change state doesn't allow abandoning of
+        the change, the response is “409 Conflict” and the error message is contained in the
+        response body.
 
         :return:
         """
-        endpoint = "/changes/%s/abandon" % self.id
-        response = self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/abandon")
 
     def restore(self):
         """
         Restores a change.
-        If the change cannot be restored because the change state doesn’t allow restoring the change,
-        the response is “409 Conflict” and the error message is contained in the response body.
+        If the change cannot be restored because the change state doesn't allow restoring the
+        change, the response is “409 Conflict” and the error message is contained in the
+        response body.
 
         :return:
         """
-        endpoint = "/changes/%s/restore" % self.id
-        response = self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/restore")
 
     def rebase(self, input_):
         """
-        Rebases a change.
+        Rebase a change.
         If the change cannot be rebased, e.g. due to conflicts, the response is '409 Conflict'
         and the error message is contained in the response body.
 
@@ -287,20 +244,15 @@ class GerritChange(BaseModel):
                 "base" : "1234",
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.rebase(input_)
 
         :param input_: the RebaseInput entity,
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#rebase-input
         :return:
         """
-        endpoint = "/changes/%s/rebase" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/rebase",
+                                json=input_, headers=self.gerrit.default_headers)
 
     def move(self, input_):
         """
@@ -314,39 +266,39 @@ class GerritChange(BaseModel):
                 "destination_branch" : "release-branch"
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.move(input_)
 
         :param input_: the MoveInput entity,
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#move-input
         :return:
         """
-        endpoint = "/changes/%s/move" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/move",
+                                json=input_,
+                                headers=self.gerrit.default_headers)
 
     def revert(self, input_=None):
         """
         Reverts a change.
-        The request body does not need to include a RevertInput entity if no review comment is added.
+        The request body does not need to include a RevertInput entity if no review comment is
+        added.
 
-        If the user doesn’t have revert permission on the change or upload permission on the destination branch,
-        the response is '403 Forbidden', and the error message is contained in the response body.
+        If the user doesn't have revert permission on the change or upload permission on the
+        destination branch, the response is '403 Forbidden', and the error message is contained in
+        the response body.
 
-        If the change cannot be reverted because the change state doesn't allow reverting the change,
-        the response is 409 Conflict and the error message is contained in the response body.
+        If the change cannot be reverted because the change state doesn't allow reverting the
+        change, the response is 409 Conflict and the error message is contained in the
+        response body.
 
         .. code-block:: python
 
             input_ = {
-                "message" : "Message to be added as review comment to the change when reverting the change."
+                "message" : "Message to be added as review comment to the change when reverting the
+                change."
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.revert()
             # or
             result = change.revert(input_)
@@ -355,22 +307,18 @@ class GerritChange(BaseModel):
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#revert-input
         :return:
         """
-        endpoint = "/changes/%s/revert" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_ or {}, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/revert",
+                                json=input_ or {}, headers=self.gerrit.default_headers)
 
     def revert_submission(self):
         """
         Creates open revert changes for all of the changes of a certain submission.
 
-        If the user doesn’t have revert permission on the change or upload permission on the destination,
-        the response is '403 Forbidden', and the error message is contained in the response body.
+        If the user doesn't have revert permission on the change or upload permission on the
+        destination, the response is '403 Forbidden', and the error message is contained in the
+        response body.
 
-        If the change cannot be reverted because the change state doesn’t allow reverting the change
+        If the change cannot be reverted because the change state doesn't allow reverting the change
         the response is '409 Conflict', and the error message is contained in the response body.
 
         :return:
@@ -379,18 +327,16 @@ class GerritChange(BaseModel):
         if parse(version) < parse("3.2.0"):
             raise UnsupportMethod("The server does not support this method")
 
-        endpoint = "/changes/%s/revert_submission" % self.id
-        response = self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/revert_submission")
 
     def submit(self, input_):
         """
         Submits  a change.
         Submitting a change also removes all users from the attention set.
 
-        If the change cannot be submitted because the submit rule doesn't allow submitting the change,
-        the response is 409 Conflict and the error message is contained in the response body.
+        If the change cannot be submitted because the submit rule doesn't allow submitting
+        the change, the response is 409 Conflict and the error message is contained in the
+        response body.
 
         .. code-block:: python
 
@@ -398,20 +344,15 @@ class GerritChange(BaseModel):
                 "on_behalf_of": 1001439
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.submit(input_)
 
         :param input_: the SubmitInput entity,
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#submit-input
         :return:
         """
-        endpoint = "/changes/%s/submit" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/submit",
+                                json=input_, headers=self.gerrit.default_headers)
 
     def delete(self):
         """
@@ -419,8 +360,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s" % self.id
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint)
 
     def get_include_in(self):
         """
@@ -428,10 +368,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/in" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/in")
 
     def index(self):
         """
@@ -439,8 +376,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/index" % self.id
-        self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.post(self.endpoint + "/index")
 
     def list_comments(self):
         """
@@ -448,10 +384,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/comments" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/comments")
 
     def list_robot_comments(self):
         """
@@ -459,10 +392,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/robotcomments" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/robotcomments")
 
     def list_drafts(self):
         """
@@ -470,29 +400,24 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/drafts" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/drafts")
 
     def consistency_check(self):
         """
-        Performs consistency checks on the change, and returns a ChangeInfo entity with the problems field set to
-        a list of ProblemInfo entities.
+        Performs consistency checks on the change, and returns a ChangeInfo entity with the problems
+        field set to a list of ProblemInfo entities.
 
         :return:
         """
-        endpoint = "/changes/%s/check" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/check")
 
     def fix(self, input_=None):
         """
         Performs consistency checks on the change as with GET /check,
-        and additionally fixes any problems that can be fixed automatically. The returned field values reflect any fixes.
-        Some fixes have options controlling their behavior, which can be set in the FixInput entity body.
-        Only the change owner, a project owner, or an administrator may fix changes.
+        and additionally fixes any problems that can be fixed automatically. The returned field
+        values reflect any fixes.
+        Some fixes have options controlling their behavior, which can be set in the FixInput
+        entity body. Only the change owner, a project owner, or an administrator may fix changes.
 
         .. code-block:: python
 
@@ -501,7 +426,7 @@ class GerritChange(BaseModel):
                 "expect_merged_as": "something"
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.fix()
             # or
             result = change.fix(input_)
@@ -510,15 +435,11 @@ class GerritChange(BaseModel):
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#fix-input
         :return:
         """
-        endpoint = "/changes/%s/check" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
+        endpoint = self.endpoint + "/check"
         if input_ is None:
-            response = self.gerrit.requester.post(base_url)
+            result = self.gerrit.post(endpoint)
         else:
-            response = self.gerrit.requester.post(
-                base_url, json=input_, headers=self.gerrit.default_headers
-            )
-        result = self.gerrit.decode_response(response)
+            result = self.gerrit.post(endpoint, json=input_, headers=self.gerrit.default_headers)
         return result
 
     def set_work_in_progress(self, input_=None):
@@ -527,7 +448,8 @@ class GerritChange(BaseModel):
         Changes may only be marked not ready by the owner, project owners or site administrators.
         Marking a change work in progress also removes all users from the attention set.
 
-        The request body does not need to include a WorkInProgressInput entity if no review comment is added.
+        The request body does not need to include a WorkInProgressInput entity if no review comment
+        is added.
 
         .. code-block:: python
 
@@ -535,26 +457,26 @@ class GerritChange(BaseModel):
                 "message": "Refactoring needs to be done before we can proceed here."
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.set_work_in_progress(input_)
             # or
             result = change.set_work_in_progress()
 
         :param input_: the WorkInProgressInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#work-in-progress-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
+          #work-in-progress-input
         :return:
         """
-        endpoint = "/changes/%s/wip" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        self.gerrit.requester.post(
-            base_url, json=input_ or {}, headers=self.gerrit.default_headers
-        )
+        self.gerrit.post(self.endpoint + "/wip",
+                         json=input_ or {}, headers=self.gerrit.default_headers
+                         )
 
     def set_ready_for_review(self, input_):
         """
         Marks the change as ready for review (set WIP property to false).
         Changes may only be marked ready by the owner, project owners or site administrators.
-        Marking a change ready for review also adds all of the reviewers of the change to the attention set.
+        Marking a change ready for review also adds all of the reviewers of the change to the
+        attention set.
 
         .. code-block:: python
 
@@ -562,18 +484,15 @@ class GerritChange(BaseModel):
                 'message': 'Refactoring is done.'
             }
 
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             change.set_ready_for_review(input_)
 
         :param input_: the WorkInProgressInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#work-in-progress-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
+          #work-in-progress-input
         :return:
         """
-        endpoint = "/changes/%s/ready" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
+        self.gerrit.post(self.endpoint + "/ready", json=input_, headers=self.gerrit.default_headers)
 
     def mark_private(self, input_):
         """
@@ -585,18 +504,16 @@ class GerritChange(BaseModel):
             input_ = {
                 "message": "After this security fix has been released we can make it public now."
             }
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             change.mark_private(input_)
 
         :param input_: the PrivateInput entity,
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#private-input
         :return:
         """
-        endpoint = "/changes/%s/private" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
+        self.gerrit.post(self.endpoint + "/private",
+                         json=input_, headers=self.gerrit.default_headers
+                         )
 
     def unmark_private(self, input_=None):
         """
@@ -608,7 +525,7 @@ class GerritChange(BaseModel):
             input_ = {
                 "message": "This is a security fix that must not be public."
             }
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             change.unmark_private(input_)
             # or
             change.unmark_private()
@@ -618,25 +535,21 @@ class GerritChange(BaseModel):
         :return:
         """
         if input_ is None:
-            endpoint = "/changes/%s/private" % self.id
-            self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+            self.gerrit.delete(self.endpoint + "/private")
         else:
-            endpoint = "/changes/%s/private.delete" % self.id
-            base_url = self.gerrit.get_endpoint_url(endpoint)
-            self.gerrit.requester.post(
-                base_url, json=input_, headers=self.gerrit.default_headers
-            )
+            self.gerrit.post(self.endpoint + "/private.delete",
+                             json=input_, headers=self.gerrit.default_headers
+                             )
 
     def ignore(self):
         """
-        Marks a change as ignored. The change will not be shown in the incoming reviews dashboard, and email
-        notifications will be suppressed. Ignoring a change does not cause the change’s "updated" timestamp to be
-        modified, and the owner is not notified.
+        Marks a change as ignored. The change will not be shown in the incoming reviews' dashboard,
+        and email notifications will be suppressed. Ignoring a change does not cause the change’s
+        "updated" timestamp to be modified, and the owner is not notified.
 
         :return:
         """
-        endpoint = "/changes/%s/ignore" % self.id
-        self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.put(self.endpoint + "/ignore")
 
     def unignore(self):
         """
@@ -644,8 +557,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/unignore" % self.id
-        self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.put(self.endpoint + "/unignore")
 
     def mark_as_reviewed(self):
         """
@@ -653,8 +565,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/reviewed" % self.id
-        self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.put(self.endpoint + "/reviewed")
 
     def mark_as_unreviewed(self):
         """
@@ -662,8 +573,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/unreviewed" % self.id
-        self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.put(self.endpoint + "/unreviewed")
 
     def get_hashtags(self):
         """
@@ -671,10 +581,7 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/hashtags" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + "/hashtags")
 
     def set_hashtags(self, input_):
         """
@@ -690,20 +597,16 @@ class GerritChange(BaseModel):
                     "hashtag2"
                 ]
             }
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.set_hashtags(input_)
 
         :param input_: the HashtagsInput entity,
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#hashtags-input
         :return:
         """
-        endpoint = "/changes/%s/hashtags" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.post(self.endpoint + "/hashtags",
+                                json=input_, headers=self.gerrit.default_headers)
+
 
     @property
     def messages(self):
@@ -717,10 +620,8 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/edit" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return GerritChangeEdit.parse(result, change=self.id, gerrit=self.gerrit)
+        result = self.gerrit.get(self.endpoint + "/edit")
+        return GerritChangeEdit(json=result, change=self.id, gerrit=self.gerrit)
 
     def create_empty_edit(self):
         """
@@ -728,17 +629,15 @@ class GerritChange(BaseModel):
 
         :return:
         """
-        endpoint = "/changes/%s/edit" % self.id
-        self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.post(self.endpoint + "/edit")
 
     @property
     def reviewers(self):
         return GerritChangeReviewers(change=self.id, gerrit=self.gerrit)
 
     def __get_revisions(self):
-        endpoint = "/changes/?q=%s&o=ALL_REVISIONS" % self.number
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        [result] = self.gerrit.decode_response(response)
+        endpoint = f"/changes/?q={self.number}&o=ALL_REVISIONS"
+        [result] = self.gerrit.get(endpoint)
         self.revisions = {}
         for revision_sha, revision in result["revisions"].items():
             if result["current_revision"] == revision_sha:
@@ -789,10 +688,7 @@ class GerritChange(BaseModel):
         if parse(version) < parse("3.3.0"):
             raise UnsupportMethod("The server does not support this method")
 
-        endpoint = "/changes/%s/attention" % self.id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(f"/changes/{self.id}/attention")
 
     def add_to_attention_set(self, input_):
         """
@@ -808,23 +704,20 @@ class GerritChange(BaseModel):
                 "user": "John Doe",
                 "reason": "reason"
             }
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             result = change.add_to_attention_set(input_)
 
         :param input_: the AttentionSetInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#attention-set-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
+          #attention-set-input
         :return:
         """
         version = self.gerrit.version
         if parse(version) < parse("3.3.0"):
             raise UnsupportMethod("The server does not support this method")
 
-        endpoint = "/changes/%s/attention" % self.id
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.post(self.endpoint + "/attention",
+                                  json=input_, headers=self.gerrit.default_headers)
         return result
 
     def remove_from_attention_set(self, id_, input_=None):
@@ -840,28 +733,24 @@ class GerritChange(BaseModel):
             input_ = {
                 "reason": "reason"
             }
-            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('Project~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             change.remove_from_attention_set('kevin.shi', input_)
             # or
             change.remove_from_attention_set('kevin.shi')
 
         :param id_: account id
         :param input_: the AttentionSetInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#attention-set-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html
+          #attention-set-input
         :return:
         """
         version = self.gerrit.version
         if parse(version) < parse("3.3.0"):
             raise UnsupportMethod("The server does not support this method")
 
+        endpoint = self.endpoint + f"/attention/{id_}"
         if input_ is None:
-            endpoint = "/changes/%s/attention/%s" % (self.id, id_)
-            self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+            self.gerrit.delete(endpoint)
         else:
-            endpoint = "/changes/%s/attention/%s/delete" % (self.id, id_)
-            base_url = self.gerrit.get_endpoint_url(endpoint)
-            response = self.gerrit.requester.post(
-                base_url, json=input_, headers=self.gerrit.default_headers
-            )
-            result = self.gerrit.decode_response(response)
-            return result
+            endpoint += "/delete"
+            return self.gerrit.post(endpoint, json=input_, headers=self.gerrit.default_headers)
