@@ -11,6 +11,7 @@ from gerrit.projects.project import GerritProject
 class GerritProjects(object):
     def __init__(self, gerrit):
         self.gerrit = gerrit
+        self.endpoint = "/projects/"
 
     def list(
         self,
@@ -41,7 +42,8 @@ class GerritProjects(object):
                             added to the output result
         :param branch: Limit the results to the projects having the specified branch
                        and include the sha1 of the branch in the results.
-        :param state: Get all projects with the given state. May not be used together with the all option.
+        :param state: Get all projects with the given state. May not be used together with the all
+        option.
 
         :return:
         """
@@ -76,23 +78,21 @@ class GerritProjects(object):
         params["all"] = int(is_all)
         params["d"] = int(description)
 
-        endpoint = "/projects/"
-        response = self.gerrit.requester.get(
-            self.gerrit.get_endpoint_url(endpoint), params
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint, params=params)
 
     def search(self, query, limit=None, skip=None):
         """
-        Queries projects visible to the caller. The query string must be provided by the query parameter.
+        Queries projects visible to the caller. The query string must be provided by the
+        query parameter.
         The start and limit parameters can be used to skip/limit results.
 
         query parameter
           * name:'NAME' Matches projects that have exactly the name 'NAME'.
           * parent:'PARENT' Matches projects that have 'PARENT' as parent project.
-          * inname:'NAME' Matches projects that a name part that starts with 'NAME' (case insensitive).
-          * description:'DESCRIPTION' Matches projects whose description contains 'DESCRIPTION', using a full-text search.
+          * inname:'NAME' Matches projects that a name part that starts with
+           'NAME' (case insensitive).
+          * description:'DESCRIPTION' Matches projects whose description contains 'DESCRIPTION',
+          using a full-text search.
           * state:'STATE' Matches project’s state. Can be either 'active' or 'read-only'.
 
         :param query:
@@ -104,12 +104,7 @@ class GerritProjects(object):
         """
         params = {k: v for k, v in (("limit", limit), ("start", skip)) if v is not None}
 
-        endpoint = "/projects/?query=%s" % query
-        response = self.gerrit.requester.get(
-            self.gerrit.get_endpoint_url(endpoint), params
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + f"/?query={query}", params=params)
 
     def get(self, name):
         """
@@ -118,10 +113,8 @@ class GerritProjects(object):
         :param name: the name of the project
         :return:
         """
-        endpoint = "/projects/%s" % quote_plus(name)
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return GerritProject.parse(result, gerrit=self.gerrit)
+        result = self.gerrit.get(self.endpoint + f"/{quote_plus(name)}")
+        return GerritProject(json=result, gerrit=self.gerrit)
 
     def create(self, project_name, input_):
         """
@@ -144,13 +137,10 @@ class GerritProjects(object):
 
         :return:
         """
-        endpoint = "/projects/%s" % quote_plus(project_name)
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return GerritProject.parse(result, gerrit=self.gerrit)
+        result = self.gerrit.put(
+            self.endpoint + f"/{quote_plus(project_name)}",
+            json=input_, headers=self.gerrit.default_headers)
+        return GerritProject(json=result, gerrit=self.gerrit)
 
     def delete(self, project_name):
         """
@@ -159,5 +149,4 @@ class GerritProjects(object):
         :param project_name: project name
         :return:
         """
-        endpoint = "/projects/%s/delete-project~delete" % quote_plus(project_name)
-        self.gerrit.requester.post(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.post(self.endpoint + f"/{quote_plus(project_name)}/delete-project~delete")
