@@ -13,8 +13,9 @@ class GerritProjectTag(BaseModel):
     tag_prefix = "refs/tags/"
 
     def __init__(self, **kwargs):
-        super(GerritProjectTag, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.entity_name = "ref"
+        self.endpoint = f"/projects/{self.project}/tags"
 
     @property
     def name(self):
@@ -26,8 +27,7 @@ class GerritProjectTag(BaseModel):
 
         :return:
         """
-        endpoint = "/projects/%s/tags/%s" % (self.project, self.name)
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + f"/{self.name}")
 
 
 class GerritProjectTags(object):
@@ -36,6 +36,7 @@ class GerritProjectTags(object):
     def __init__(self, project, gerrit):
         self.project = project
         self.gerrit = gerrit
+        self.endpoint = f"/projects/{self.project}/tags"
 
     def list(self, pattern_dispatcher=None, limit=None, skip=None):
         """
@@ -59,12 +60,7 @@ class GerritProjectTags(object):
                 raise ValueError("Pattern types can be either 'match' or 'regex'.")
 
         params = {k: v for k, v in (("n", limit), ("s", skip), (p, v)) if v is not None}
-        endpoint = "/projects/{}/tags/".format(self.project)
-        response = self.gerrit.requester.get(
-            self.gerrit.get_endpoint_url(endpoint), params
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint, params=params)
 
     def get(self, name):
         """
@@ -73,10 +69,8 @@ class GerritProjectTags(object):
         :param name: the tag ref
         :return:
         """
-        endpoint = "/projects/%s/tags/%s" % (self.project, quote_plus(name))
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
-        return GerritProjectTag.parse(result, project=self.project, gerrit=self.gerrit)
+        result = self.gerrit.get(self.endpoint + f"/{quote_plus(name)}")
+        return GerritProjectTag(json=result, project=self.project, gerrit=self.gerrit)
 
     def create(self, name, input_):
         """
@@ -97,13 +91,8 @@ class GerritProjectTags(object):
           https://gerrit-review.googlesource.com/Documentation/rest-api-projects.html#tag-input
         :return:
         """
-        endpoint = "/projects/%s/tags/%s" % (self.project, name)
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.put(
+            self.endpoint + f"/{name}", json=input_, headers=self.gerrit.default_headers)
 
     def delete(self, name):
         """
@@ -112,6 +101,4 @@ class GerritProjectTags(object):
         :param name: the tag ref
         :return:
         """
-        endpoint = "/projects/%s/tags/%s" % (self.project, quote_plus(name))
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        self.gerrit.requester.delete(base_url)
+        self.gerrit.delete(self.endpoint + f"/{quote_plus(name)}")
