@@ -7,8 +7,9 @@ from gerrit.utils.models import BaseModel
 
 class GerritProjectWebHook(BaseModel):
     def __init__(self, **kwargs):
-        super(GerritProjectWebHook, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.entity_name = "name"
+        self.endpoint = f"/config/server/webhooks~projects/{self.project}/remotes"
 
     def delete(self):
         """
@@ -16,17 +17,14 @@ class GerritProjectWebHook(BaseModel):
 
         :return:
         """
-        endpoint = "/config/server/webhooks~projects/%s/remotes/%s" % (
-            self.project,
-            self.name,
-        )
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + f"/{self.name}")
 
 
 class GerritProjectWebHooks(object):
     def __init__(self, project, gerrit):
         self.project = project
         self.gerrit = gerrit
+        self.endpoint = f"/config/server/webhooks~projects/{self.project}/remotes"
 
     def list(self):
         """
@@ -34,9 +32,7 @@ class GerritProjectWebHooks(object):
 
         :return:
         """
-        endpoint = "/config/server/webhooks~projects/%s/remotes/" % self.project
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint)
 
         webhooks = []
         for key, value in result.items():
@@ -67,18 +63,9 @@ class GerritProjectWebHooks(object):
         :param input_: the RemoteInfo entity
         :return:
         """
-        endpoint = "/config/server/webhooks~projects/%s/remotes/%s" % (
-            self.project,
-            name,
-        )
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.put(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return GerritProjectWebHook.parse(
-            result, project=self.project, gerrit=self.gerrit
-        )
+        result = self.gerrit.put(
+            self.endpoint + f"/{name}", json=input_, headers=self.gerrit.default_headers)
+        return GerritProjectWebHook(json=result, project=self.project, gerrit=self.gerrit)
 
     def get(self, name):
         """
@@ -87,16 +74,9 @@ class GerritProjectWebHooks(object):
         :param name: the webhook name
         :return:
         """
-        endpoint = "/config/server/webhooks~projects/%s/remotes/%s" % (
-            self.project,
-            name,
-        )
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + f"/{name}")
         result.update({"name": name})
-        return GerritProjectWebHook.parse(
-            result, project=self.project, gerrit=self.gerrit
-        )
+        return GerritProjectWebHook(json=result, project=self.project, gerrit=self.gerrit)
 
     def delete(self, name):
         """
@@ -105,8 +85,4 @@ class GerritProjectWebHooks(object):
         :param name: the webhook name
         :return:
         """
-        endpoint = "/config/server/webhooks~projects/%s/remotes/%s" % (
-            self.project,
-            name,
-        )
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + f"/{name}")
