@@ -7,6 +7,7 @@ from gerrit.utils.exceptions import (
     NotAllowedError,
     ValidationError,
     AuthError,
+    UnauthorizedError,
     NotFoundError,
     ConflictError,
     ClientError,
@@ -62,15 +63,11 @@ class Requester(object):
             request_kwargs["auth"] = (self.username, self.password)
 
         if params:
-            assert isinstance(params, dict), "Params must be a dict, got %s" % repr(
-                params
-            )
+            assert isinstance(params, dict), f"Params must be a dict, got {repr(params)}"
             request_kwargs["params"] = params
 
         if headers:
-            assert isinstance(headers, dict), "headers must be a dict, got %s" % repr(
-                headers
-            )
+            assert isinstance(headers, dict), f"headers must be a dict, got {repr(headers)}"
             request_kwargs["headers"] = headers
 
         if self.AUTH_COOKIE:
@@ -94,7 +91,15 @@ class Requester(object):
 
         return request_kwargs
 
-    def get(self, url, params=None, headers=None, allow_redirects=True, stream=False, **kwargs):
+    def get(
+        self,
+        url,
+        params=None,
+        headers=None,
+        allow_redirects=True,
+        stream=False,
+        **kwargs
+    ):
         """
         :param url:
         :param params:
@@ -213,18 +218,10 @@ class Requester(object):
             reason = res.reason
 
         if 400 <= res.status_code < 500:
-            http_error_msg = u"%s Client Error: %s for url: %s" % (
-                res.status_code,
-                reason,
-                res.url,
-            )
+            http_error_msg = f"{res.status_code} Client Error: {reason} for url: {res.url}"
 
         elif 500 <= res.status_code < 600:
-            http_error_msg = u"%s Server Error: %s for url: %s" % (
-                res.status_code,
-                reason,
-                res.url,
-            )
+            http_error_msg = f"{res.status_code} Server Error: {reason} for url: {res.url}"
 
         if res.status_code < 300:
             # OK, return http response
@@ -234,6 +231,10 @@ class Requester(object):
             # Validation error
             raise ValidationError(http_error_msg)
 
+        elif res.status_code == 401:
+            # Unauthorized error
+            raise UnauthorizedError(http_error_msg)
+
         elif res.status_code == 403:
             # Auth error
             raise AuthError(http_error_msg)
